@@ -1,22 +1,9 @@
 /*
     This file is part of Akonadi Contact.
 
-    Copyright (c) 2007-2009 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2007-2009 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "contactgroupeditordialog.h"
@@ -46,10 +33,7 @@ class Q_DECL_HIDDEN ContactGroupEditorDialog::Private
 public:
     Private(ContactGroupEditorDialog *qq, ContactGroupEditorDialog::Mode mode)
         : q(qq)
-        , mAddressBookBox(nullptr)
-        , mEditor(nullptr)
         , mMode(mode)
-        , okButton(nullptr)
     {
     }
 
@@ -78,7 +62,7 @@ public:
         group.sync();
     }
 
-    ContactGroupEditorDialog *q;
+    ContactGroupEditorDialog *const q;
     CollectionComboBox *mAddressBookBox = nullptr;
     ContactGroupEditor *mEditor = nullptr;
     ContactGroupEditorDialog::Mode mMode;
@@ -90,7 +74,7 @@ ContactGroupEditorDialog::ContactGroupEditorDialog(Mode mode, QWidget *parent)
     , d(new Private(this, mode))
 {
     setWindowTitle(mode == CreateMode ? i18n("New Contact Group") : i18n("Edit Contact Group"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     d->okButton = buttonBox->button(QDialogButtonBox::Ok);
@@ -106,7 +90,7 @@ ContactGroupEditorDialog::ContactGroupEditorDialog(Mode mode, QWidget *parent)
 
     QWidget *mainWidget = new QWidget(this);
 
-    QGridLayout *layout = new QGridLayout(mainWidget);
+    auto *layout = new QGridLayout(mainWidget);
     layout->setContentsMargins(0, 0, 0, 0);
 
     d->mEditor = new Akonadi::ContactGroupEditor(mode == CreateMode
