@@ -1,22 +1,9 @@
 /*
     This file is part of Akonadi Contact.
 
-    Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2009 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "contactgroupmodel_p.h"
@@ -33,17 +20,11 @@
 using namespace Akonadi;
 
 struct GroupMember {
-    GroupMember()
-        : isReference(false)
-        , loadingError(false)
-    {
-    }
-
     KContacts::ContactGroup::ContactReference reference;
     KContacts::ContactGroup::Data data;
     KContacts::Addressee referencedContact;
-    bool isReference;
-    bool loadingError;
+    bool isReference = false;
+    bool loadingError = false;
 };
 
 class Q_DECL_HIDDEN ContactGroupModel::Private
@@ -62,7 +43,7 @@ public:
         } else {
             item.setId(reference.uid().toLongLong());
         }
-        ItemFetchJob *job = new ItemFetchJob(item, mParent);
+        auto *job = new ItemFetchJob(item, mParent);
         job->setProperty("row", row);
         job->fetchScope().fetchFullPayload();
 
@@ -81,7 +62,7 @@ public:
             return;
         }
 
-        ItemFetchJob *fetchJob = qobject_cast<ItemFetchJob *>(job);
+        auto *fetchJob = qobject_cast<ItemFetchJob *>(job);
 
         if (fetchJob->items().count() != 1) {
             mMembers[row].loadingError = true;
