@@ -33,10 +33,10 @@ public:
     };
 
     explicit AddressLocationWidget(QWidget *parent = nullptr);
-    ~AddressLocationWidget();
+    ~AddressLocationWidget() override;
 
     void setAddress(const KContacts::Address &address);
-    KContacts::Address address() const;
+    Q_REQUIRED_RESULT KContacts::Address address() const;
 
     void slotModifyAddress(const KContacts::Address &address, int currentIndex);
 
@@ -44,12 +44,14 @@ public:
 
     void setReadOnly(bool readOnly);
 
+    Q_REQUIRED_RESULT bool wasChanged() const;
 Q_SIGNALS:
     void addNewAddress(const KContacts::Address &address);
     void updateAddress(const KContacts::Address &address, int index);
     void updateAddressCanceled();
 
 private:
+    void slotChanged();
     void slotAddAddress();
     void slotUpdateAddress();
     void slotCancelModifyAddress();
@@ -71,6 +73,7 @@ private:
     SelectAddressTypeComboBox *mTypeCombo = nullptr;
     int mCurrentAddress = -1;
     Mode mCurrentMode;
+    bool mWasChanged = false;
 };
 
 }
