@@ -1,23 +1,10 @@
 /*
     This file is part of Contact Editor.
 
-    Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016-2020 Laurent Montel <montel.org>
+    SPDX-FileCopyrightText: 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
+    SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "generalinfowidget.h"
@@ -42,19 +29,19 @@ using namespace ContactEditor;
 GeneralInfoWidget::GeneralInfoWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QHBoxLayout *topLayout = new QHBoxLayout(this);
+    auto *topLayout = new QHBoxLayout(this);
 
-    QVBoxLayout *photoLayout = new QVBoxLayout;
+    auto *photoLayout = new QVBoxLayout;
     topLayout->addLayout(photoLayout);
     mPhotoWidget = new ImageWidget(ImageWidget::Photo);
     mPhotoWidget->setObjectName(QStringLiteral("photowidget"));
     photoLayout->addWidget(mPhotoWidget);
     photoLayout->addStretch(1);
 
-    QVBoxLayout *leftLayout = new QVBoxLayout;
+    auto *leftLayout = new QVBoxLayout;
     topLayout->addLayout(leftLayout);
 
-    QVBoxLayout *rightLayout = new QVBoxLayout;
+    auto *rightLayout = new QVBoxLayout;
     topLayout->addLayout(rightLayout);
 
     mNameWidget = new NameWidget(this);
@@ -82,7 +69,7 @@ GeneralInfoWidget::GeneralInfoWidget(QWidget *parent)
     rightLayout->addWidget(mMailListWidget);
 
     QWidget *categoryWidget = new QWidget(this);
-    QVBoxLayout *categoryWidgetLayout = new QVBoxLayout(categoryWidget);
+    auto *categoryWidgetLayout = new QVBoxLayout(categoryWidget);
     categoryWidgetLayout->setContentsMargins(0, 0, 0, 0);
     QLabel *label = new QLabel(i18n("Tags"), this);
     label->setObjectName(QStringLiteral("categorylabel"));
