@@ -1,23 +1,10 @@
 /*
     This file is part of Contact Editor.
 
-    Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016-2020 Laurent Montel <montel.org>
+    SPDX-FileCopyrightText: 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
+    SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "phonewidgetlister.h"
@@ -48,7 +35,7 @@ void PhoneWidgetLister::loadContact(const KContacts::Addressee &contact)
         auto wIt = widgetList.constBegin();
         auto wEnd = widgetList.constEnd();
         for (int i = 0; wIt != wEnd; ++wIt, ++i) {
-            PhoneWidget *w = qobject_cast<PhoneWidget *>(*wIt);
+            auto *w = qobject_cast<PhoneWidget *>(*wIt);
             w->loadPhone(phoneNumbers.at(i));
         }
     }
@@ -59,7 +46,7 @@ void PhoneWidgetLister::storeContact(KContacts::Addressee &contact) const
     KContacts::PhoneNumber::List phoneNumbers;
     const QList<QWidget *> widgetList = widgets();
     for (QWidget *widget : widgetList) {
-        PhoneWidget *w = qobject_cast<PhoneWidget *>(widget);
+        auto *w = qobject_cast<PhoneWidget *>(widget);
         KContacts::PhoneNumber number = w->storePhone();
         if (!number.isEmpty()) {
             phoneNumbers << number;
@@ -72,14 +59,14 @@ void PhoneWidgetLister::setReadOnly(bool readOnly)
 {
     const QList<QWidget *> widgetList = widgets();
     for (QWidget *widget : widgetList) {
-        PhoneWidget *w = qobject_cast<PhoneWidget *>(widget);
+        auto *w = qobject_cast<PhoneWidget *>(widget);
         w->setReadOnly(readOnly);
     }
 }
 
 QWidget *PhoneWidgetLister::createWidget(QWidget *parent)
 {
-    PhoneWidget *w = new PhoneWidget(parent);
+    auto *w = new PhoneWidget(parent);
     reconnectWidget(w);
     return w;
 }
@@ -131,7 +118,7 @@ void PhoneWidgetLister::updateAddRemoveButton()
     }
 
     for (QWidget *widget : widgetList) {
-        PhoneWidget *w = qobject_cast<PhoneWidget *>(widget);
+        auto *w = qobject_cast<PhoneWidget *>(widget);
         w->updateAddRemoveButton(addButtonEnabled);
     }
 }
